@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2005, 2007, 2009-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2002, 2005, 2007, 2009-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -186,7 +186,7 @@ need_crlf (mu_stream_t str)
 
   if (mu_stream_ioctl (str, MU_IOCTL_TRANSPORT, MU_IOCTL_OP_GET, trans))
     return 1; /* suppose we do need it */
-  if (tcgetattr ((int)trans[0], &tbuf) == 0 &&
+  if (tcgetattr ((int) (intptr_t) trans[0], &tbuf) == 0 &&
       (tbuf.c_oflag & OPOST) && (tbuf.c_oflag & ONLCR))
     return 0;
   else
