@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2005, 2007-2012 Free Software Foundation,
-   Inc.
+   Copyright (C) 1999-2002, 2005, 2007-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -134,6 +134,7 @@ struct mu_cfg_param dotlock_cfg_param[] = {
 
 
 const char *dotlock_capa[] = {
+  "mailutils",
   "common",
   "debug",
   NULL
