@@ -2,8 +2,8 @@
    GNU Mailutils nntp functions.  This application interactively allows users
    to contact a nntp server.
 
-   Copyright (C) 2003-2005, 2007, 2009-2012 Free Software Foundation,
-   Inc.
+   Copyright (C) 2003-2005, 2007, 2009-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
