@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
 #
 #  GNU Mailutils is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -12,9 +12,7 @@
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with GNU Mailutils; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-#  MA 02110-1301 USA
+#  along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. 
 
 import sys
 from mailutils import stream
@@ -24,23 +22,14 @@ if len (sys.argv) != 3:
     print "usage: %s from-code to-code" % sys.argv[0]
     sys.exit (0)
 
-sti = stream.StdioStream (sys.stdin)
-sti.open ()
-
+sti = stream.StdioStream (stream.MU_STDIN_FD)
 cvt = filter.FilterIconvStream (sti, sys.argv[1], sys.argv[2])
-cvt.open ()
-
-out = stream.StdioStream (sys.stdout, 0)
-out.open ()
+out = stream.StdioStream (stream.MU_STDOUT_FD, 0)
 
 total = 0
 while True:
-    buf = cvt.read (total)
-    out.sequential_write (buf)
+    buf = cvt.read ()
+    out.write (buf)
     total += cvt.read_count
     if not cvt.read_count:
         break
-
-out.flush ()
-out.close ()
-sti.close ()
