@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2005, 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999-2005, 2007-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -200,6 +201,7 @@ static struct argp argp = {
 };
 
 static const char *frm_argp_capa[] = {
+  "mailutils",
   "common",
   "debug",
   "mailbox",
@@ -260,6 +262,7 @@ frm (char *mailbox_name)
   int status;
 
   selected = 0;
+  counter.new = counter.read = counter.unread = 0;
   frm_scan (mailbox_name, frm_select, &total);
   
   if (show_summary)
