@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2005-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -195,7 +196,8 @@ imap4d_append0 (mu_mailbox_t mbox, int flags, char *date_time, char *text,
 
 /* APPEND mbox [(flags)] [date_time] message_literal */
 int
-imap4d_append (struct imap4d_command *command, imap4d_tokbuf_t tok)
+imap4d_append (struct imap4d_session *session,
+               struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
   int i;
   char *mboxname;
