@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2005, 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 2003-2005, 2007-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,9 +28,9 @@ static Gsasl_session *sess_ctx;
 static void auth_gsasl_capa_init (int disable);
 
 static void
-finish_session (void)
+finish_session (void *ptr)
 {
-  gsasl_finish (sess_ctx);
+  gsasl_finish ((Gsasl_session *)ptr);
 }
 
 static int
@@ -170,7 +171,7 @@ auth_gsasl (struct imap4d_auth *ap)
       mu_stream_unref (newstream[0]);
       mu_stream_unref (newstream[1]);
       
-      util_atexit (finish_session);
+      mu_onexit (finish_session, sess_ctx);
       return imap4d_auth_ok;
     }
   
