@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005-2008, 2010-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999, 2001, 2005-2008, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -78,9 +78,10 @@ _auth_try (void *item, void *data)
 }
 
 void
-imap4d_auth_capability ()
+imap4d_auth_capability (struct imap4d_session *session)
 {
-  mu_list_foreach (imap_auth_list, _auth_capa, NULL);
+  if (session->tls_mode != tls_required)
+    mu_list_foreach (imap_auth_list, _auth_capa, NULL);
 }
 
 /*
@@ -102,7 +103,7 @@ imap4d_authenticate (struct imap4d_session *session,
   
   auth_type = imap4d_tokbuf_getarg (tok, IMAP4_ARG_1);
 
-  if (tls_required)
+  if (session->tls_mode == tls_required)
     return io_completion_response (command, RESP_NO,
 			           "Command disabled: Use STARTTLS first");
   
