@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2003, 2005, 2007-2008, 2010-2012 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2003, 2005, 2007-2008, 2010-2012, 2014-2015
+   Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ imap4d_capability (struct imap4d_session *session,
 
   mu_list_foreach (capa_list, print_capa, NULL);
   
-  imap4d_auth_capability ();
+  imap4d_auth_capability (session);
   io_sendf ("\n");
 
   return io_completion_response (command, RESP_OK, "Completed");
