@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001-2012, 2014-2015 Free Software Foundation,
+   Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,6 +36,8 @@ enum tls_mode tls_mode;
 int login_disabled;             /* Disable LOGIN command */
 int create_home_dir;            /* Create home directory if it does not
 				   exist */
+mu_list_t user_retain_groups;
+
 int home_dir_mode = S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH;
 
 int mailbox_mode[NS_MAX];
@@ -86,6 +89,7 @@ static struct argp argp = {
 };
 
 static const char *imap4d_capa[] = {
+  "mailutils",
   "auth",
   "common",
   "debug",
@@ -246,7 +250,32 @@ cb_mailbox_mode (void *data, mu_config_value_t *val)
     mu_error (_("invalid mode string near %s"), p);
   return 0;
 }
+
+static int
+cb2_group (const char *gname, void *data)
+{
+  mu_list_t list = data;
+  struct group *group;
+  
+  group = getgrnam (gname);
+  if (!group)
+    mu_error (_("unknown group: %s"), gname);
+  else
+    mu_list_append (list, (void*) (intptr_t) group->gr_gid);
+  return 0;
+}
+  
+static int
+cb_group (void *data, mu_config_value_t *arg)
+{
+  mu_list_t *plist = data;
 
+  if (!*plist)
+    mu_list_create (plist);
+  return mu_cfg_string_value_cb (arg, cb2_group, *plist);
+}
+
+
 struct imap4d_srv_config
 {
   struct mu_srv_config m_cfg;
@@ -284,20 +313,66 @@ cb_tls (void *data, mu_config_value_t *val)
 }
 #endif
 
+#ifdef WITH_TLS
 static int
 cb_tls_required (void *data, mu_config_value_t *val)
 {
-  int *res = data;
   int bv;
-  
+
   if (mu_cfg_assert_value_type (val, MU_CFG_STRING))
     return 1;
   if (mu_cfg_parse_boolean (val->v.string, &bv))
     mu_error (_("Not a boolean value"));
+  else if (bv)
+    {
+      tls_mode = tls_required;
+      mu_diag_output (MU_DIAG_WARNING,
+		      "the \"tls-required\" statement is deprecated, "
+		      "use \"tls required\" instead");
+    }
   else
-    *res = tls_required;
+    mu_diag_output (MU_DIAG_WARNING,
+		    "the \"tls-required\" statement is deprecated, "
+		    "use \"tls\" instead");
+    
   return 0;
 }
+#endif
+
+static mu_list_t auth_deny_user_list, auth_allow_user_list;
+static mu_list_t auth_deny_group_list, auth_allow_group_list;
+
+static int
+check_user_groups (void *item, void *data)
+{
+  char *gname = item;
+  struct group *gp;
+  char **p;
+  
+  gp = getgrnam (gname);
+  if (!gp)
+    return 0;
+
+  if (gp->gr_gid == auth_data->gid)
+    return MU_ERR_EXISTS;
+
+  for (p = gp->gr_mem; *p; p++)
+    if (strcmp (*p, auth_data->name) == 0)
+      return MU_ERR_EXISTS;
+
+  return 0;
+}
+
+static int
+imap_check_group_list (mu_list_t l)
+{
+  int rc = mu_list_foreach (l, check_user_groups, NULL);
+  if (rc == MU_ERR_EXISTS) 
+    return 0;
+  else if (rc == 0)
+    return MU_ERR_NOENT;
+  return rc;
+}
 
 static struct mu_cfg_param imap4d_srv_param[] = {
 #ifdef WITH_TLS
@@ -309,6 +384,19 @@ static struct mu_cfg_param imap4d_srv_param[] = {
 };
 
 static struct mu_cfg_param imap4d_cfg_param[] = {
+  { "allow-users", MU_CFG_LIST_OF(mu_cfg_string), &auth_allow_user_list,
+    0, NULL, 
+    N_("Allow access to users from this list.") },
+  { "deny-users", MU_CFG_LIST_OF(mu_cfg_string), &auth_deny_user_list,
+    0, NULL, 
+    N_("Deny access to users from this list.") },
+  { "allow-groups", MU_CFG_LIST_OF(mu_cfg_string), &auth_allow_group_list,
+    0, NULL, 
+    N_("Allow access if the user group is in this list.") },
+  { "deny-groups", MU_CFG_LIST_OF(mu_cfg_string), &auth_deny_group_list,
+    0, NULL, 
+    N_("Deny access if the user group is in this list.") },
+  
   { "homedir", mu_cfg_string, &modify_homedir, 0, NULL,
     N_("Modify home directory.") },
   { "personal-namespace", MU_CFG_LIST_OF(mu_cfg_string), &namespace[NS_PRIVATE],
@@ -333,6 +421,9 @@ static struct mu_cfg_param imap4d_cfg_param[] = {
   { "home-dir-mode", mu_cfg_callback, NULL, 0, cb_mode,
     N_("File mode for creating user home directories (octal)."),
     N_("mode") },
+  { "retain-groups", mu_cfg_callback, &user_retain_groups, 0, cb_group,
+    N_("Retain these supplementary groups when switching to user privileges"),
+    N_("groups: list of string") },
 #ifdef WITH_TLS
   { "tls", mu_cfg_callback, &tls_mode, 0, cb_tls,
     N_("Kind of TLS encryption to use") },
@@ -364,9 +455,78 @@ static struct mu_cfg_param imap4d_cfg_param[] = {
   { NULL }
 };
 
+int
+mu_get_user_groups (const char *user, mu_list_t retain, mu_list_t *pgrouplist)
+{
+  int rc;
+  struct group *gr;
+  mu_list_t list;
+	
+  if (!*pgrouplist)
+    {
+      rc = mu_list_create (pgrouplist);
+      if (rc)
+	{
+	  mu_error(_("%s: cannot create list: %s"),
+		   "mu_get_user_groups", mu_strerror (rc));
+	  return rc;
+	}
+    }
+
+  list = *pgrouplist;
+  setgrent ();
+  for (rc = 0; rc == 0 && (gr = getgrent ()); )
+    {
+      char **p;
+      for (p = gr->gr_mem; *p; p++)
+	if (strcmp (*p, user) == 0)
+	  {
+	    if (retain
+		&& mu_list_locate (retain, (void*) (intptr_t) gr->gr_gid,
+				   NULL))
+	      continue;
+	      
+	    /* FIXME: Avoid duplicating gids */
+	    rc = mu_list_append (list, (void*) (intptr_t) gr->gr_gid);
+	    if (rc) 
+	      mu_error(_("%s: cannot append to list: %s"),
+		       "mu_get_user_groups",
+		       mu_strerror (rc));
+	    break;
+	  }
+    }
+  endgrent ();
+  return rc;
+}
+
 int
 imap4d_session_setup0 ()
 {
+  if (auth_deny_user_list &&
+      mu_list_locate (auth_deny_user_list, auth_data->name, NULL) == 0)
+    {
+      mu_error (_("%s is in deny-users, rejecting"), auth_data->name);
+      return 1;
+    }
+  if (auth_allow_user_list &&
+      mu_list_locate (auth_allow_user_list, auth_data->name, NULL))
+    {
+      mu_error (_("%s is not in allow-users, rejecting"), auth_data->name);
+      return 1;
+    }
+  if (auth_deny_group_list &&
+      imap_check_group_list (auth_deny_group_list) == 0)
+    {
+      mu_error (_("%s is in deny-groups, rejecting"), auth_data->name);
+      return 1;
+    }
+  if (auth_allow_group_list &&
+      imap_check_group_list (auth_allow_group_list))
+    {
+      mu_error (_("%s is not in allow-groups, rejecting"), auth_data->name);
+      return 1;
+    }
+
   real_homedir = mu_normalize_path (mu_strdup (auth_data->dir));
   if (imap4d_check_home_dir (real_homedir, auth_data->uid, auth_data->gid))
     return 1;
@@ -418,7 +578,48 @@ imap4d_session_setup0 ()
     }
   
   if (auth_data->change_uid)
-    setuid (auth_data->uid);
+    {
+      struct group *gr;
+      mu_list_t groups = NULL;
+      int rc;
+      uid_t uid;
+
+      uid = getuid ();
+      if (uid != auth_data->uid)
+	{
+	  rc = mu_list_create (&groups);
+	  if (rc)
+	    {
+	      mu_error(_("cannot create list: %s"), mu_strerror (rc));
+	      free (imap4d_homedir);
+	      free (real_homedir);
+	      return 1;
+	    }
+	  mu_list_append (groups, (void*) (intptr_t) auth_data->gid);
+
+	  rc = mu_get_user_groups (auth_data->name, user_retain_groups,
+				   &groups);
+	  if (rc)
+	    {
+	      /* FIXME: When mu_get_user_groups goes to the library, add a
+		 diag message here */
+	      free (imap4d_homedir);
+	      free (real_homedir);
+	      return 1;
+	    }
+	  gr = getgrnam ("mail");
+	  rc = mu_switch_to_privs (auth_data->uid, gr->gr_gid, groups);
+	  mu_list_destroy (&groups);
+	  if (rc)
+	    {
+	      mu_error (_("can't switch to user %s privileges: %s"),
+			auth_data->name, mu_strerror (rc));
+	      free (imap4d_homedir);
+	      free (real_homedir);
+	      return 1;
+	    }
+	}
+    }
 
   util_chdir (imap4d_homedir);
   namespace_init_session (imap4d_homedir);
@@ -586,6 +787,7 @@ imap4d_mainloop (int ifd, int ofd, enum tls_mode tls)
     {
     case tls_required:
       imap4d_capability_add (IMAP_CAPA_XTLSREQUIRED);
+      break;
     case tls_no:
       imap4d_capability_remove (IMAP_CAPA_STARTTLS);
       tls_available = 0;
@@ -655,7 +857,8 @@ imap4d_connection (int fd, struct sockaddr *sa, int salen,
   else
     rc = 1;
   
-  imap4d_mainloop (fd, fd, cfg->tls_mode);
+  imap4d_mainloop (fd, fd, 
+                   cfg->tls_mode == tls_unspecified ? tls_mode : cfg->tls_mode);
 
   if (rc == 0)
     clr_strerr_flt ();
@@ -851,7 +1054,7 @@ main (int argc, char **argv)
     {
       /* Make sure we are in the root directory.  */
       chdir ("/");
-      status = imap4d_mainloop (MU_STDIN_FD, MU_STDOUT_FD, 0);
+      status = imap4d_mainloop (MU_STDIN_FD, MU_STDOUT_FD, tls_mode);
     }
 
   if (status)
