@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001-2012, 2014-2015 Free Software Foundation,
+   Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,9 +16,39 @@
    along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "imap4d.h"
+#include <mailutils/property.h>
 
 mu_stream_t iostream;
 
+static void
+log_cipher (mu_stream_t stream)
+{
+  mu_property_t prop;
+  int rc = mu_stream_ioctl (stream, MU_IOCTL_TLSSTREAM,
+			    MU_IOCTL_TLS_GET_CIPHER_INFO, &prop);
+  if (rc)
+    {
+      mu_diag_output (MU_DIAG_INFO, _("TLS established"));
+      mu_diag_output (MU_DIAG_ERROR, _("can't get TLS details: %s"),
+		      mu_strerror (rc));
+    }
+  else
+    {
+      char const *cipher, *mac, *proto;
+      if (mu_property_sget_value (prop, "cipher", &cipher))
+	cipher = "UNKNOWN";	
+      if (mu_property_sget_value (prop, "mac", &mac))
+	mac = "UNKNOWN";
+      if (mu_property_sget_value (prop, "protocol", &proto))
+	proto = "UNKNOWN";
+      
+      mu_diag_output (MU_DIAG_INFO, _("TLS established using %s-%s (%s)"),
+		      cipher, mac, proto);
+      
+      mu_property_destroy (&prop);
+    }
+}
+
 void
 io_setio (int ifd, int ofd, int tls)
 {
@@ -48,7 +79,7 @@ io_setio (int ifd, int ofd, int tls)
 	  mu_error (_("failed to create TLS stream: %s"), mu_strerror (rc));
 	  imap4d_bye (ERR_STREAM_CREATE);
 	}
-      tls_encryption_on ();
+      log_cipher (str);
     }
   else
 #endif
@@ -112,6 +143,8 @@ imap4d_init_tls_server ()
       return 1;
     }
 
+  log_cipher (tlsstream);
+
   mu_stream_unref (stream[0]);
   mu_stream_unref (stream[1]);
   stream[0] = stream[1] = tlsstream;
@@ -160,7 +193,26 @@ sc2string (int rc)
 int
 io_copy_out (mu_stream_t str, size_t size)
 {
-  return mu_stream_copy (iostream, str, size, NULL);
+  int rc;
+  struct mu_buffer_query oldbuf, newbuf;
+  
+  oldbuf.type = MU_TRANSPORT_OUTPUT;
+  if (mu_stream_ioctl (iostream, MU_IOCTL_TRANSPORT_BUFFER,
+		       MU_IOCTL_OP_GET, &oldbuf) == 0)
+    {
+      newbuf.type = MU_TRANSPORT_OUTPUT;
+      newbuf.buftype = mu_buffer_full;
+      newbuf.bufsize = 64*1024;
+      mu_stream_ioctl (iostream, MU_IOCTL_TRANSPORT_BUFFER,
+		       MU_IOCTL_OP_SET, &newbuf);
+    }
+
+  rc = mu_stream_copy (iostream, str, size, NULL);
+
+  mu_stream_ioctl (iostream, MU_IOCTL_TRANSPORT_BUFFER,
+		   MU_IOCTL_OP_SET, &oldbuf);
+
+  return rc;
 }
 
 int
@@ -437,16 +489,17 @@ imap4d_tokbuf_decrlf (struct imap4d_tokbuf *tok, size_t off, size_t *plen)
   size_t len = *plen;
   char *p, *end = buf + len;
 
-  for (p = end - 1; p > buf; p--)
+  for (p = buf; p < end; )
     {
-      if (*p == '\n' && p > buf && p[-1] == '\r')
+      if (*p == '\r' && p + 1 < end && p[1] == '\n')
 	{
-	  memmove (p - 1, p, end - p);
-	  end--;
-	  p--;
+	  p++;
+	  len--;
 	}
+      else
+	*buf++ = *p++;
     }
-  *plen = end - buf;
+  *plen = len;
 }	  
 
 static void
