@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2002, 2005, 2007-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999, 2001-2002, 2005, 2007-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -313,8 +313,8 @@ imap4d_search0 (imap4d_tokbuf_t tok, int isuid, char **err_text)
   parsebuf.tree = parse_search_key_list (&parsebuf);
   if (!parsebuf.tree)
     {
+      *err_text = parsebuf.err_mesg ? parsebuf.err_mesg : "Parse error";
       parse_free_mem (&parsebuf);
-      *err_text = "Parse error";
       return RESP_BAD;
     }
 
