@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001-2012, 2014-2015 Free Software Foundation,
+   Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ util_getfullpath (const char *name)
 }
 
 int
-util_do_command (imap4d_tokbuf_t tok)
+util_do_command (struct imap4d_session *session, imap4d_tokbuf_t tok)
 {
   char *tag, *cmd;
   struct imap4d_command *command;
@@ -73,7 +74,7 @@ util_do_command (imap4d_tokbuf_t tok)
   if (command->states && (command->states & state) == 0)
     return io_completion_response (command, RESP_BAD, "Wrong state");
 
-  return command->func (command, tok);
+  return command->func (session, command, tok);
 }
 
 struct imap4d_command *
@@ -272,29 +273,11 @@ util_uidvalidity (mu_mailbox_t smbox, unsigned long *uidvp)
   return mu_mailbox_uidvalidity (smbox, uidvp);
 }
 
-static mu_list_t atexit_list;
-
-void
-util_atexit (void (*fp) (void))
-{
-  if (!atexit_list)
-    mu_list_create (&atexit_list);
-  mu_list_append (atexit_list, (void*)fp);
-}
-
-static int
-atexit_run (void *item, void *data)
-{
-  ((void (*) (void)) item) ();
-  return 0;
-}
-
 void
 util_bye ()
 {
   mu_stream_close (iostream);
   mu_stream_destroy (&iostream);
-  mu_list_foreach (atexit_list, atexit_run, 0);
 }
 
 void
