@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2005, 2007, 2009-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2001, 2005, 2007, 2009-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -61,13 +61,6 @@ extern int  mu_folder_enumerate      (mu_folder_t, const char *,
 extern int  mu_folder_lsub           (mu_folder_t, const char *, const char *,
 				      mu_list_t *);
 
-/* Stream settings.  */
-extern int  mu_folder_get_stream     (mu_folder_t, mu_stream_t *)
-                                       __attribute__ ((deprecated));
-extern int  mu_folder_get_streamref  (mu_folder_t, mu_stream_t *);
-  
-extern int  mu_folder_set_stream     (mu_folder_t, mu_stream_t);
-
   /* Match function */
 extern int mu_folder_set_match (mu_folder_t folder, mu_folder_match_fp pmatch);
 extern int mu_folder_get_match (mu_folder_t folder,
