@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2005-2007, 2010-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2001, 2005-2007, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -134,12 +134,10 @@ extern int mu_message_set_header (mu_message_t, mu_header_t, void *);
 extern int mu_message_get_body (mu_message_t, mu_body_t *);
 extern int mu_message_set_body (mu_message_t, mu_body_t, void *);
 
-extern int mu_message_get_stream (mu_message_t, mu_stream_t *)
-                                   __attribute__((deprecated));
+extern int mu_message_get_stream (mu_message_t, mu_stream_t *) MU_DEPRECATED;
 extern int mu_message_get_streamref (mu_message_t, mu_stream_t *);
 
-extern int mu_message_set_stream (mu_message_t, mu_stream_t, void *)
-  __attribute__((deprecated));
+extern int mu_message_set_stream (mu_message_t, mu_stream_t, void *);
 
 extern int mu_message_get_attribute (mu_message_t, mu_attribute_t *);
 extern int mu_message_set_attribute (mu_message_t, mu_attribute_t, void *);
