@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2007, 2010-2012 Free Software Foundation,
-   Inc.
+   Copyright (C) 1999-2001, 2007, 2010-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,7 @@ struct _mu_body
 {
   void *owner;
   mu_stream_t stream;
+  mu_stream_t rawstream;
   mu_stream_t fstream;
   int flags;
 
