@@ -1,6 +1,6 @@
 /* Free an array of string pointers.
-   Copyright (C) 1999-2001, 2003-2006, 2010-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2001, 2003-2006, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
