@@ -1,8 +1,8 @@
 /* sha1.c - Functions to compute SHA1 message digest of files or
    memory blocks according to the NIST specification FIPS-180-1.
 
-   Copyright (C) 2000-2001, 2003-2006, 2010-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 2000-2001, 2003-2006, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
