@@ -1,9 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.4.2.  */
+/* A Bison parser, made by GNU Bison 2.5.1.  */
 
-/* Skeleton implementation for Bison's Yacc-like parsers in C
+/* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2006, 2009-2010 Free Software
-   Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.4.2"
+#define YYBISON_VERSION "2.5.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -66,11 +65,11 @@
 
 /* Copy the first part of user declarations.  */
 
-/* Line 189 of yacc.c  */
+/* Line 268 of yacc.c  */
 #line 1 "parser.y"
 
 /* cfg_parser.y -- general-purpose configuration file parser
-   Copyright (C) 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 2007-2012, 2014-2015 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -240,8 +239,16 @@ mu_cfg_create_node_list (mu_list_t *plist)
 
 
 
-/* Line 189 of yacc.c  */
-#line 245 "parser.c"
+/* Line 268 of yacc.c  */
+#line 244 "parser.c"
+
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -287,7 +294,7 @@ mu_cfg_create_node_list (mu_list_t *plist)
 typedef union YYSTYPE
 {
 
-/* Line 214 of yacc.c  */
+/* Line 295 of yacc.c  */
 #line 173 "parser.y"
 
   mu_cfg_node_t node;
@@ -300,8 +307,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 214 of yacc.c  */
-#line 305 "parser.c"
+/* Line 295 of yacc.c  */
+#line 312 "parser.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define mu_cfg_yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -312,8 +319,8 @@ typedef union YYSTYPE
 /* Copy the second part of user declarations.  */
 
 
-/* Line 264 of yacc.c  */
-#line 317 "parser.c"
+/* Line 345 of yacc.c  */
+#line 324 "parser.c"
 
 #ifdef short
 # undef short
@@ -416,11 +423,12 @@ YYID (mu_cfg_yyi)
 #    define alloca _alloca
 #   else
 #    define YYSTACK_ALLOC alloca
-#    if ! defined _ALLOCA_H && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
+#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 #     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#     ifndef _STDLIB_H
-#      define _STDLIB_H 1
+      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
+#     ifndef EXIT_SUCCESS
+#      define EXIT_SUCCESS 0
 #     endif
 #    endif
 #   endif
@@ -443,24 +451,24 @@ YYID (mu_cfg_yyi)
 #  ifndef YYSTACK_ALLOC_MAXIMUM
 #   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
 #  endif
-#  if (defined __cplusplus && ! defined _STDLIB_H \
+#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
        && ! ((defined YYMALLOC || defined malloc) \
 	     && (defined YYFREE || defined free)))
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#   ifndef _STDLIB_H
-#    define _STDLIB_H 1
+#   ifndef EXIT_SUCCESS
+#    define EXIT_SUCCESS 0
 #   endif
 #  endif
 #  ifndef YYMALLOC
 #   define YYMALLOC malloc
-#   if ! defined malloc && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
+#   if ! defined malloc && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
 #   endif
 #  endif
 #  ifndef YYFREE
 #   define YYFREE free
-#   if ! defined free && ! defined _STDLIB_H && (defined __STDC__ || defined __C99__FUNC__ \
+#   if ! defined free && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 void free (void *); /* INFRINGES ON USER NAME SPACE */
 #   endif
@@ -489,23 +497,7 @@ union mu_cfg_yyalloc
      ((N) * (sizeof (mu_cfg_yytype_int16) + sizeof (YYSTYPE)) \
       + YYSTACK_GAP_MAXIMUM)
 
-/* Copy COUNT objects from FROM to TO.  The source and destination do
-   not overlap.  */
-# ifndef YYCOPY
-#  if defined __GNUC__ && 1 < __GNUC__
-#   define YYCOPY(To, From, Count) \
-      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
-#  else
-#   define YYCOPY(To, From, Count)		\
-      do					\
-	{					\
-	  YYSIZE_T mu_cfg_yyi;				\
-	  for (mu_cfg_yyi = 0; mu_cfg_yyi < (Count); mu_cfg_yyi++)	\
-	    (To)[mu_cfg_yyi] = (From)[mu_cfg_yyi];		\
-	}					\
-      while (YYID (0))
-#  endif
-# endif
+# define YYCOPY_NEEDED 1
 
 /* Relocate STACK from its old location to the new one.  The
    local variables YYSIZE and YYSTACKSIZE give the old and new number of
@@ -525,6 +517,26 @@ union mu_cfg_yyalloc
 
 #endif
 
+#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
+/* Copy COUNT objects from SRC to DST.  The source and destination do
+   not overlap.  */
+# ifndef YYCOPY
+#  if defined __GNUC__ && 1 < __GNUC__
+#   define YYCOPY(Dst, Src, Count) \
+      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
+#  else
+#   define YYCOPY(Dst, Src, Count)              \
+      do                                        \
+        {                                       \
+          YYSIZE_T mu_cfg_yyi;                         \
+          for (mu_cfg_yyi = 0; mu_cfg_yyi < (Count); mu_cfg_yyi++)   \
+            (Dst)[mu_cfg_yyi] = (Src)[mu_cfg_yyi];            \
+        }                                       \
+      while (YYID (0))
+#  endif
+# endif
+#endif /* !YYCOPY_NEEDED */
+
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  8
 /* YYLAST -- Last index in YYTABLE.  */
@@ -621,7 +633,7 @@ static const char *const mu_cfg_yytname[] =
   "MU_TOK_QSTRING", "MU_TOK_MSTRING", "';'", "'{'", "'}'", "'('", "')'",
   "','", "$accept", "input", "stmtlist", "stmt", "simple", "block",
   "ident", "tag", "vallist", "vlist", "value", "string", "slist", "slist0",
-  "list", "values", "opt_sc", 0
+  "list", "values", "opt_sc", YY_NULL
 };
 #endif
 
@@ -653,8 +665,8 @@ static const mu_cfg_yytype_uint8 mu_cfg_yyr2[] =
        1
 };
 
-/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
-   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
+/* YYDEFACT[STATE-NAME] -- Default reduction number in state STATE-NUM.
+   Performed when YYTABLE doesn't specify something else to do.  Zero
    means the default is an error.  */
 static const mu_cfg_yytype_uint8 mu_cfg_yydefact[] =
 {
@@ -691,8 +703,7 @@ static const mu_cfg_yytype_int8 mu_cfg_yypgoto[] =
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
    positive, shift that token.  If negative, reduce the rule which
-   number is the opposite.  If zero, do what YYDEFACT says.
-   If YYTABLE_NINF, syntax error.  */
+   number is the opposite.  If YYTABLE_NINF, syntax error.  */
 #define YYTABLE_NINF -1
 static const mu_cfg_yytype_uint8 mu_cfg_yytable[] =
 {
@@ -701,6 +712,12 @@ static const mu_cfg_yytype_uint8 mu_cfg_yytable[] =
       12,    13,    25,    26,    28,    14,    32,    35,    38,     9
 };
 
+#define mu_cfg_yypact_value_is_default(mu_cfg_yystate) \
+  ((mu_cfg_yystate) == (-14))
+
+#define mu_cfg_yytable_value_is_error(mu_cfg_yytable_value) \
+  YYID (0)
+
 static const mu_cfg_yytype_uint8 mu_cfg_yycheck[] =
 {
        3,    14,     3,     3,    17,     3,     4,     5,     6,     9,
@@ -745,18 +762,18 @@ static const mu_cfg_yytype_uint8 mu_cfg_yystos[] =
 
 #define YYRECOVERING()  (!!mu_cfg_yyerrstatus)
 
-#define YYBACKUP(Token, Value)					\
-do								\
-  if (mu_cfg_yychar == YYEMPTY && mu_cfg_yylen == 1)				\
-    {								\
-      mu_cfg_yychar = (Token);						\
-      mu_cfg_yylval = (Value);						\
-      mu_cfg_yytoken = YYTRANSLATE (mu_cfg_yychar);				\
-      YYPOPSTACK (1);						\
-      goto mu_cfg_yybackup;						\
-    }								\
-  else								\
-    {								\
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (mu_cfg_yychar == YYEMPTY)                                        \
+    {                                                           \
+      mu_cfg_yychar = (Token);                                         \
+      mu_cfg_yylval = (Value);                                         \
+      YYPOPSTACK (mu_cfg_yylen);                                       \
+      mu_cfg_yystate = *mu_cfg_yyssp;                                         \
+      goto mu_cfg_yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
       mu_cfg_yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
@@ -793,19 +810,10 @@ while (YYID (0))
 #endif
 
 
-/* YY_LOCATION_PRINT -- Print the location on the stream.
-   This macro was not mandated originally: define only if we know
-   we won't break user code: when these are the locations we know.  */
+/* This macro is provided for backward compatibility. */
 
 #ifndef YY_LOCATION_PRINT
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
-# else
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
+# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
@@ -860,6 +868,8 @@ mu_cfg_yy_symbol_value_print (mu_cfg_yyoutput, mu_cfg_yytype, mu_cfg_yyvaluep)
     YYSTYPE const * const mu_cfg_yyvaluep;
 #endif
 {
+  FILE *mu_cfg_yyo = mu_cfg_yyoutput;
+  YYUSE (mu_cfg_yyo);
   if (!mu_cfg_yyvaluep)
     return;
 # ifdef YYPRINT
@@ -997,7 +1007,6 @@ int mu_cfg_yydebug;
 # define YYMAXDEPTH 10000
 #endif
 
-
 
 #if YYERROR_VERBOSE
 
@@ -1100,115 +1109,142 @@ mu_cfg_yytnamerr (char *mu_cfg_yyres, const char *mu_cfg_yystr)
 }
 # endif
 
-/* Copy into YYRESULT an error message about the unexpected token
-   YYCHAR while in state YYSTATE.  Return the number of bytes copied,
-   including the terminating null byte.  If YYRESULT is null, do not
-   copy anything; just return the number of bytes that would be
-   copied.  As a special case, return 0 if an ordinary "syntax error"
-   message will do.  Return YYSIZE_MAXIMUM if overflow occurs during
-   size calculation.  */
-static YYSIZE_T
-mu_cfg_yysyntax_error (char *mu_cfg_yyresult, int mu_cfg_yystate, int mu_cfg_yychar)
+/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
+   about the unexpected token YYTOKEN for the state stack whose top is
+   YYSSP.
+
+   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
+   not large enough to hold the message.  In that case, also set
+   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
+   required number of bytes is too large to store.  */
+static int
+mu_cfg_yysyntax_error (YYSIZE_T *mu_cfg_yymsg_alloc, char **mu_cfg_yymsg,
+                mu_cfg_yytype_int16 *mu_cfg_yyssp, int mu_cfg_yytoken)
 {
-  int mu_cfg_yyn = mu_cfg_yypact[mu_cfg_yystate];
+  YYSIZE_T mu_cfg_yysize0 = mu_cfg_yytnamerr (YY_NULL, mu_cfg_yytname[mu_cfg_yytoken]);
+  YYSIZE_T mu_cfg_yysize = mu_cfg_yysize0;
+  YYSIZE_T mu_cfg_yysize1;
+  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
+  /* Internationalized format string. */
+  const char *mu_cfg_yyformat = YY_NULL;
+  /* Arguments of mu_cfg_yyformat. */
+  char const *mu_cfg_yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
+  /* Number of reported tokens (one for the "unexpected", one per
+     "expected"). */
+  int mu_cfg_yycount = 0;
 
-  if (! (YYPACT_NINF < mu_cfg_yyn && mu_cfg_yyn <= YYLAST))
-    return 0;
-  else
+  /* There are many possibilities here to consider:
+     - Assume YYFAIL is not used.  It's too flawed to consider.  See
+       <http://lists.gnu.org/archive/html/bison-patches/2009-12/msg00024.html>
+       for details.  YYERROR is fine as it does not invoke this
+       function.
+     - If this state is a consistent state with a default action, then
+       the only way this function was invoked is if the default action
+       is an error action.  In that case, don't check for expected
+       tokens because there are none.
+     - The only way there can be no lookahead present (in mu_cfg_yychar) is if
+       this state is a consistent state with a default action.  Thus,
+       detecting the absence of a lookahead is sufficient to determine
+       that there is no unexpected or expected token to report.  In that
+       case, just report a simple "syntax error".
+     - Don't assume there isn't a lookahead just because this state is a
+       consistent state with a default action.  There might have been a
+       previous inconsistent state, consistent state with a non-default
+       action, or user semantic action that manipulated mu_cfg_yychar.
+     - Of course, the expected token list depends on states to have
+       correct lookahead information, and it depends on the parser not
+       to perform extra reductions after fetching a lookahead from the
+       scanner and before detecting a syntax error.  Thus, state merging
+       (from LALR or IELR) and default reductions corrupt the expected
+       token list.  However, the list is correct for canonical LR with
+       one exception: it will still contain any token that will not be
+       accepted due to an error action in a later state.
+  */
+  if (mu_cfg_yytoken != YYEMPTY)
     {
-      int mu_cfg_yytype = YYTRANSLATE (mu_cfg_yychar);
-      YYSIZE_T mu_cfg_yysize0 = mu_cfg_yytnamerr (0, mu_cfg_yytname[mu_cfg_yytype]);
-      YYSIZE_T mu_cfg_yysize = mu_cfg_yysize0;
-      YYSIZE_T mu_cfg_yysize1;
-      int mu_cfg_yysize_overflow = 0;
-      enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
-      char const *mu_cfg_yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
-      int mu_cfg_yyx;
+      int mu_cfg_yyn = mu_cfg_yypact[*mu_cfg_yyssp];
+      mu_cfg_yyarg[mu_cfg_yycount++] = mu_cfg_yytname[mu_cfg_yytoken];
+      if (!mu_cfg_yypact_value_is_default (mu_cfg_yyn))
+        {
+          /* Start YYX at -YYN if negative to avoid negative indexes in
+             YYCHECK.  In other words, skip the first -YYN actions for
+             this state because they are default actions.  */
+          int mu_cfg_yyxbegin = mu_cfg_yyn < 0 ? -mu_cfg_yyn : 0;
+          /* Stay within bounds of both mu_cfg_yycheck and mu_cfg_yytname.  */
+          int mu_cfg_yychecklim = YYLAST - mu_cfg_yyn + 1;
+          int mu_cfg_yyxend = mu_cfg_yychecklim < YYNTOKENS ? mu_cfg_yychecklim : YYNTOKENS;
+          int mu_cfg_yyx;
 
-# if 0
-      /* This is so xgettext sees the translatable formats that are
-	 constructed on the fly.  */
-      YY_("syntax error, unexpected %s");
-      YY_("syntax error, unexpected %s, expecting %s");
-      YY_("syntax error, unexpected %s, expecting %s or %s");
-      YY_("syntax error, unexpected %s, expecting %s or %s or %s");
-      YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
-# endif
-      char *mu_cfg_yyfmt;
-      char const *mu_cfg_yyf;
-      static char const mu_cfg_yyunexpected[] = "syntax error, unexpected %s";
-      static char const mu_cfg_yyexpecting[] = ", expecting %s";
-      static char const mu_cfg_yyor[] = " or %s";
-      char mu_cfg_yyformat[sizeof mu_cfg_yyunexpected
-		    + sizeof mu_cfg_yyexpecting - 1
-		    + ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
-		       * (sizeof mu_cfg_yyor - 1))];
-      char const *mu_cfg_yyprefix = mu_cfg_yyexpecting;
-
-      /* Start YYX at -YYN if negative to avoid negative indexes in
-	 YYCHECK.  */
-      int mu_cfg_yyxbegin = mu_cfg_yyn < 0 ? -mu_cfg_yyn : 0;
-
-      /* Stay within bounds of both mu_cfg_yycheck and mu_cfg_yytname.  */
-      int mu_cfg_yychecklim = YYLAST - mu_cfg_yyn + 1;
-      int mu_cfg_yyxend = mu_cfg_yychecklim < YYNTOKENS ? mu_cfg_yychecklim : YYNTOKENS;
-      int mu_cfg_yycount = 1;
-
-      mu_cfg_yyarg[0] = mu_cfg_yytname[mu_cfg_yytype];
-      mu_cfg_yyfmt = mu_cfg_yystpcpy (mu_cfg_yyformat, mu_cfg_yyunexpected);
-
-      for (mu_cfg_yyx = mu_cfg_yyxbegin; mu_cfg_yyx < mu_cfg_yyxend; ++mu_cfg_yyx)
-	if (mu_cfg_yycheck[mu_cfg_yyx + mu_cfg_yyn] == mu_cfg_yyx && mu_cfg_yyx != YYTERROR)
-	  {
-	    if (mu_cfg_yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
-	      {
-		mu_cfg_yycount = 1;
-		mu_cfg_yysize = mu_cfg_yysize0;
-		mu_cfg_yyformat[sizeof mu_cfg_yyunexpected - 1] = '\0';
-		break;
-	      }
-	    mu_cfg_yyarg[mu_cfg_yycount++] = mu_cfg_yytname[mu_cfg_yyx];
-	    mu_cfg_yysize1 = mu_cfg_yysize + mu_cfg_yytnamerr (0, mu_cfg_yytname[mu_cfg_yyx]);
-	    mu_cfg_yysize_overflow |= (mu_cfg_yysize1 < mu_cfg_yysize);
-	    mu_cfg_yysize = mu_cfg_yysize1;
-	    mu_cfg_yyfmt = mu_cfg_yystpcpy (mu_cfg_yyfmt, mu_cfg_yyprefix);
-	    mu_cfg_yyprefix = mu_cfg_yyor;
-	  }
-
-      mu_cfg_yyf = YY_(mu_cfg_yyformat);
-      mu_cfg_yysize1 = mu_cfg_yysize + mu_cfg_yystrlen (mu_cfg_yyf);
-      mu_cfg_yysize_overflow |= (mu_cfg_yysize1 < mu_cfg_yysize);
-      mu_cfg_yysize = mu_cfg_yysize1;
-
-      if (mu_cfg_yysize_overflow)
-	return YYSIZE_MAXIMUM;
-
-      if (mu_cfg_yyresult)
-	{
-	  /* Avoid sprintf, as that infringes on the user's name space.
-	     Don't have undefined behavior even if the translation
-	     produced a string with the wrong number of "%s"s.  */
-	  char *mu_cfg_yyp = mu_cfg_yyresult;
-	  int mu_cfg_yyi = 0;
-	  while ((*mu_cfg_yyp = *mu_cfg_yyf) != '\0')
-	    {
-	      if (*mu_cfg_yyp == '%' && mu_cfg_yyf[1] == 's' && mu_cfg_yyi < mu_cfg_yycount)
-		{
-		  mu_cfg_yyp += mu_cfg_yytnamerr (mu_cfg_yyp, mu_cfg_yyarg[mu_cfg_yyi++]);
-		  mu_cfg_yyf += 2;
-		}
-	      else
-		{
-		  mu_cfg_yyp++;
-		  mu_cfg_yyf++;
-		}
-	    }
-	}
-      return mu_cfg_yysize;
+          for (mu_cfg_yyx = mu_cfg_yyxbegin; mu_cfg_yyx < mu_cfg_yyxend; ++mu_cfg_yyx)
+            if (mu_cfg_yycheck[mu_cfg_yyx + mu_cfg_yyn] == mu_cfg_yyx && mu_cfg_yyx != YYTERROR
+                && !mu_cfg_yytable_value_is_error (mu_cfg_yytable[mu_cfg_yyx + mu_cfg_yyn]))
+              {
+                if (mu_cfg_yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
+                  {
+                    mu_cfg_yycount = 1;
+                    mu_cfg_yysize = mu_cfg_yysize0;
+                    break;
+                  }
+                mu_cfg_yyarg[mu_cfg_yycount++] = mu_cfg_yytname[mu_cfg_yyx];
+                mu_cfg_yysize1 = mu_cfg_yysize + mu_cfg_yytnamerr (YY_NULL, mu_cfg_yytname[mu_cfg_yyx]);
+                if (! (mu_cfg_yysize <= mu_cfg_yysize1
+                       && mu_cfg_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  return 2;
+                mu_cfg_yysize = mu_cfg_yysize1;
+              }
+        }
     }
+
+  switch (mu_cfg_yycount)
+    {
+# define YYCASE_(N, S)                      \
+      case N:                               \
+        mu_cfg_yyformat = S;                       \
+      break
+      YYCASE_(0, YY_("syntax error"));
+      YYCASE_(1, YY_("syntax error, unexpected %s"));
+      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
+      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
+      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
+      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
+# undef YYCASE_
+    }
+
+  mu_cfg_yysize1 = mu_cfg_yysize + mu_cfg_yystrlen (mu_cfg_yyformat);
+  if (! (mu_cfg_yysize <= mu_cfg_yysize1 && mu_cfg_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    return 2;
+  mu_cfg_yysize = mu_cfg_yysize1;
+
+  if (*mu_cfg_yymsg_alloc < mu_cfg_yysize)
+    {
+      *mu_cfg_yymsg_alloc = 2 * mu_cfg_yysize;
+      if (! (mu_cfg_yysize <= *mu_cfg_yymsg_alloc
+             && *mu_cfg_yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
+        *mu_cfg_yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
+      return 1;
+    }
+
+  /* Avoid sprintf, as that infringes on the user's name space.
+     Don't have undefined behavior even if the translation
+     produced a string with the wrong number of "%s"s.  */
+  {
+    char *mu_cfg_yyp = *mu_cfg_yymsg;
+    int mu_cfg_yyi = 0;
+    while ((*mu_cfg_yyp = *mu_cfg_yyformat) != '\0')
+      if (*mu_cfg_yyp == '%' && mu_cfg_yyformat[1] == 's' && mu_cfg_yyi < mu_cfg_yycount)
+        {
+          mu_cfg_yyp += mu_cfg_yytnamerr (mu_cfg_yyp, mu_cfg_yyarg[mu_cfg_yyi++]);
+          mu_cfg_yyformat += 2;
+        }
+      else
+        {
+          mu_cfg_yyp++;
+          mu_cfg_yyformat++;
+        }
+  }
+  return 0;
 }
 #endif /* YYERROR_VERBOSE */
-
 
 /*-----------------------------------------------.
 | Release the memory associated to this symbol.  |
@@ -1241,6 +1277,7 @@ mu_cfg_yydestruct (mu_cfg_yymsg, mu_cfg_yytype, mu_cfg_yyvaluep)
     }
 }
 
+
 /* Prevent warnings from -Wmissing-prototypes.  */
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
@@ -1267,10 +1304,9 @@ YYSTYPE mu_cfg_yylval;
 int mu_cfg_yynerrs;
 
 
-
-/*-------------------------.
-| mu_cfg_yyparse or mu_cfg_yypush_parse.  |
-`-------------------------*/
+/*----------.
+| mu_cfg_yyparse.  |
+`----------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1294,8 +1330,6 @@ mu_cfg_yyparse ()
 #endif
 #endif
 {
-
-
     int mu_cfg_yystate;
     /* Number of tokens to shift before error messages enabled.  */
     int mu_cfg_yyerrstatus;
@@ -1304,7 +1338,7 @@ mu_cfg_yyparse ()
        `mu_cfg_yyss': related to states.
        `mu_cfg_yyvs': related to semantic values.
 
-       Refer to the stacks thru separate pointers, to allow mu_cfg_yyoverflow
+       Refer to the stacks through separate pointers, to allow mu_cfg_yyoverflow
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
@@ -1450,7 +1484,7 @@ mu_cfg_yybackup:
 
   /* First try to decide what to do without reference to lookahead token.  */
   mu_cfg_yyn = mu_cfg_yypact[mu_cfg_yystate];
-  if (mu_cfg_yyn == YYPACT_NINF)
+  if (mu_cfg_yypact_value_is_default (mu_cfg_yyn))
     goto mu_cfg_yydefault;
 
   /* Not known => get a lookahead token if don't already have one.  */
@@ -1481,8 +1515,8 @@ mu_cfg_yybackup:
   mu_cfg_yyn = mu_cfg_yytable[mu_cfg_yyn];
   if (mu_cfg_yyn <= 0)
     {
-      if (mu_cfg_yyn == 0 || mu_cfg_yyn == YYTABLE_NINF)
-	goto mu_cfg_yyerrlab;
+      if (mu_cfg_yytable_value_is_error (mu_cfg_yyn))
+        goto mu_cfg_yyerrlab;
       mu_cfg_yyn = -mu_cfg_yyn;
       goto mu_cfg_yyreduce;
     }
@@ -1537,7 +1571,7 @@ mu_cfg_yyreduce:
     {
         case 2:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 196 "parser.y"
     {
 	    parse_node_list = (mu_cfg_yyvsp[(1) - (1)].nodelist);
@@ -1546,7 +1580,7 @@ mu_cfg_yyreduce:
 
   case 3:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 202 "parser.y"
     {
 	    mu_cfg_create_node_list (&(mu_cfg_yyval.nodelist));
@@ -1556,7 +1590,7 @@ mu_cfg_yyreduce:
 
   case 4:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 207 "parser.y"
     {
 	    mu_list_append ((mu_cfg_yyvsp[(1) - (2)].nodelist), (mu_cfg_yyvsp[(2) - (2)].pnode));
@@ -1567,7 +1601,7 @@ mu_cfg_yyreduce:
 
   case 7:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 219 "parser.y"
     {
 	    (mu_cfg_yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_param, &(mu_cfg_yyvsp[(1) - (3)].ident).locus,
@@ -1578,7 +1612,7 @@ mu_cfg_yyreduce:
 
   case 8:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 227 "parser.y"
     {
 	    (mu_cfg_yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_statement, &(mu_cfg_yyvsp[(1) - (5)].ident).locus,
@@ -1589,7 +1623,7 @@ mu_cfg_yyreduce:
 
   case 9:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 233 "parser.y"
     {
 	    (mu_cfg_yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_statement, &(mu_cfg_yyvsp[(1) - (6)].ident).locus,
@@ -1600,7 +1634,7 @@ mu_cfg_yyreduce:
 
   case 10:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 241 "parser.y"
     {
 	    (mu_cfg_yyval.ident).name = (mu_cfg_yyvsp[(1) - (1)].string);
@@ -1610,7 +1644,7 @@ mu_cfg_yyreduce:
 
   case 11:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 248 "parser.y"
     {
 	    (mu_cfg_yyval.pvalue) = NULL;
@@ -1619,7 +1653,7 @@ mu_cfg_yyreduce:
 
   case 13:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 255 "parser.y"
     {
 	    size_t n = 0;
@@ -1658,7 +1692,7 @@ mu_cfg_yyreduce:
 
   case 14:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 291 "parser.y"
     {
 	    int rc = mu_list_create (&(mu_cfg_yyval.list));
@@ -1675,7 +1709,7 @@ mu_cfg_yyreduce:
 
   case 15:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 303 "parser.y"
     {
 	    mu_list_append ((mu_cfg_yyvsp[(1) - (2)].list), config_value_dup (&(mu_cfg_yyvsp[(2) - (2)].value)));
@@ -1684,7 +1718,7 @@ mu_cfg_yyreduce:
 
   case 16:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 309 "parser.y"
     {
 	      (mu_cfg_yyval.value).type = MU_CFG_STRING;
@@ -1694,7 +1728,7 @@ mu_cfg_yyreduce:
 
   case 17:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 314 "parser.y"
     {
 	      (mu_cfg_yyval.value).type = MU_CFG_LIST;
@@ -1704,7 +1738,7 @@ mu_cfg_yyreduce:
 
   case 18:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 319 "parser.y"
     {
 	      (mu_cfg_yyval.value).type = MU_CFG_STRING;
@@ -1714,7 +1748,7 @@ mu_cfg_yyreduce:
 
   case 22:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 331 "parser.y"
     {
 	    mu_iterator_t itr;
@@ -1736,7 +1770,7 @@ mu_cfg_yyreduce:
 
   case 23:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 350 "parser.y"
     {
 	    mu_list_create (&(mu_cfg_yyval.list));
@@ -1746,7 +1780,7 @@ mu_cfg_yyreduce:
 
   case 24:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 355 "parser.y"
     {
 	    mu_list_append ((mu_cfg_yyvsp[(1) - (2)].list), (mu_cfg_yyvsp[(2) - (2)].string));
@@ -1756,7 +1790,7 @@ mu_cfg_yyreduce:
 
   case 25:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 362 "parser.y"
     {
 	      (mu_cfg_yyval.list) = (mu_cfg_yyvsp[(2) - (3)].list);
@@ -1765,7 +1799,7 @@ mu_cfg_yyreduce:
 
   case 26:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 366 "parser.y"
     {
 	      (mu_cfg_yyval.list) = (mu_cfg_yyvsp[(2) - (4)].list);
@@ -1774,7 +1808,7 @@ mu_cfg_yyreduce:
 
   case 27:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 372 "parser.y"
     {
 	    mu_list_create (&(mu_cfg_yyval.list));
@@ -1784,7 +1818,7 @@ mu_cfg_yyreduce:
 
   case 28:
 
-/* Line 1464 of yacc.c  */
+/* Line 1810 of yacc.c  */
 #line 377 "parser.y"
     {
 	    mu_list_append ((mu_cfg_yyvsp[(1) - (3)].list), config_value_dup (&(mu_cfg_yyvsp[(3) - (3)].value)));
@@ -1794,10 +1828,21 @@ mu_cfg_yyreduce:
 
 
 
-/* Line 1464 of yacc.c  */
-#line 1799 "parser.c"
+/* Line 1810 of yacc.c  */
+#line 1833 "parser.c"
       default: break;
     }
+  /* User semantic actions sometimes alter mu_cfg_yychar, and that requires
+     that mu_cfg_yytoken be updated with the new translation.  We take the
+     approach of translating immediately before every use of mu_cfg_yytoken.
+     One alternative is translating here after every semantic action,
+     but that translation would be missed if the semantic action invokes
+     YYABORT, YYACCEPT, or YYERROR immediately after altering mu_cfg_yychar or
+     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
+     incorrect destructor might then be invoked immediately.  In the
+     case of YYERROR or YYBACKUP, subsequent parser actions might lead
+     to an incorrect destructor call or verbose syntax error message
+     before the lookahead is translated.  */
   YY_SYMBOL_PRINT ("-> $$ =", mu_cfg_yyr1[mu_cfg_yyn], &mu_cfg_yyval, &mu_cfg_yyloc);
 
   YYPOPSTACK (mu_cfg_yylen);
@@ -1825,6 +1870,10 @@ mu_cfg_yyreduce:
 | mu_cfg_yyerrlab -- here on detecting error |
 `------------------------------------*/
 mu_cfg_yyerrlab:
+  /* Make sure we have latest lookahead translation.  See comments at
+     user semantic actions for why this is necessary.  */
+  mu_cfg_yytoken = mu_cfg_yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (mu_cfg_yychar);
+
   /* If not already recovering from an error, report this error.  */
   if (!mu_cfg_yyerrstatus)
     {
@@ -1832,37 +1881,36 @@ mu_cfg_yyerrlab:
 #if ! YYERROR_VERBOSE
       mu_cfg_yyerror (YY_("syntax error"));
 #else
+# define YYSYNTAX_ERROR mu_cfg_yysyntax_error (&mu_cfg_yymsg_alloc, &mu_cfg_yymsg, \
+                                        mu_cfg_yyssp, mu_cfg_yytoken)
       {
-	YYSIZE_T mu_cfg_yysize = mu_cfg_yysyntax_error (0, mu_cfg_yystate, mu_cfg_yychar);
-	if (mu_cfg_yymsg_alloc < mu_cfg_yysize && mu_cfg_yymsg_alloc < YYSTACK_ALLOC_MAXIMUM)
-	  {
-	    YYSIZE_T mu_cfg_yyalloc = 2 * mu_cfg_yysize;
-	    if (! (mu_cfg_yysize <= mu_cfg_yyalloc && mu_cfg_yyalloc <= YYSTACK_ALLOC_MAXIMUM))
-	      mu_cfg_yyalloc = YYSTACK_ALLOC_MAXIMUM;
-	    if (mu_cfg_yymsg != mu_cfg_yymsgbuf)
-	      YYSTACK_FREE (mu_cfg_yymsg);
-	    mu_cfg_yymsg = (char *) YYSTACK_ALLOC (mu_cfg_yyalloc);
-	    if (mu_cfg_yymsg)
-	      mu_cfg_yymsg_alloc = mu_cfg_yyalloc;
-	    else
-	      {
-		mu_cfg_yymsg = mu_cfg_yymsgbuf;
-		mu_cfg_yymsg_alloc = sizeof mu_cfg_yymsgbuf;
-	      }
-	  }
-
-	if (0 < mu_cfg_yysize && mu_cfg_yysize <= mu_cfg_yymsg_alloc)
-	  {
-	    (void) mu_cfg_yysyntax_error (mu_cfg_yymsg, mu_cfg_yystate, mu_cfg_yychar);
-	    mu_cfg_yyerror (mu_cfg_yymsg);
-	  }
-	else
-	  {
-	    mu_cfg_yyerror (YY_("syntax error"));
-	    if (mu_cfg_yysize != 0)
-	      goto mu_cfg_yyexhaustedlab;
-	  }
+        char const *mu_cfg_yymsgp = YY_("syntax error");
+        int mu_cfg_yysyntax_error_status;
+        mu_cfg_yysyntax_error_status = YYSYNTAX_ERROR;
+        if (mu_cfg_yysyntax_error_status == 0)
+          mu_cfg_yymsgp = mu_cfg_yymsg;
+        else if (mu_cfg_yysyntax_error_status == 1)
+          {
+            if (mu_cfg_yymsg != mu_cfg_yymsgbuf)
+              YYSTACK_FREE (mu_cfg_yymsg);
+            mu_cfg_yymsg = (char *) YYSTACK_ALLOC (mu_cfg_yymsg_alloc);
+            if (!mu_cfg_yymsg)
+              {
+                mu_cfg_yymsg = mu_cfg_yymsgbuf;
+                mu_cfg_yymsg_alloc = sizeof mu_cfg_yymsgbuf;
+                mu_cfg_yysyntax_error_status = 2;
+              }
+            else
+              {
+                mu_cfg_yysyntax_error_status = YYSYNTAX_ERROR;
+                mu_cfg_yymsgp = mu_cfg_yymsg;
+              }
+          }
+        mu_cfg_yyerror (mu_cfg_yymsgp);
+        if (mu_cfg_yysyntax_error_status == 2)
+          goto mu_cfg_yyexhaustedlab;
       }
+# undef YYSYNTAX_ERROR
 #endif
     }
 
@@ -1921,7 +1969,7 @@ mu_cfg_yyerrlab1:
   for (;;)
     {
       mu_cfg_yyn = mu_cfg_yypact[mu_cfg_yystate];
-      if (mu_cfg_yyn != YYPACT_NINF)
+      if (!mu_cfg_yypact_value_is_default (mu_cfg_yyn))
 	{
 	  mu_cfg_yyn += YYTERROR;
 	  if (0 <= mu_cfg_yyn && mu_cfg_yyn <= YYLAST && mu_cfg_yycheck[mu_cfg_yyn] == YYTERROR)
@@ -1968,7 +2016,7 @@ mu_cfg_yyabortlab:
   mu_cfg_yyresult = 1;
   goto mu_cfg_yyreturn;
 
-#if !defined(mu_cfg_yyoverflow) || YYERROR_VERBOSE
+#if !defined mu_cfg_yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | mu_cfg_yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1980,8 +2028,13 @@ mu_cfg_yyexhaustedlab:
 
 mu_cfg_yyreturn:
   if (mu_cfg_yychar != YYEMPTY)
-     mu_cfg_yydestruct ("Cleanup: discarding lookahead",
-		 mu_cfg_yytoken, &mu_cfg_yylval);
+    {
+      /* Make sure we have latest lookahead translation.  See comments at
+         user semantic actions for why this is necessary.  */
+      mu_cfg_yytoken = YYTRANSLATE (mu_cfg_yychar);
+      mu_cfg_yydestruct ("Cleanup: discarding lookahead",
+                  mu_cfg_yytoken, &mu_cfg_yylval);
+    }
   /* Do not reclaim the symbols of the rule which action triggered
      this YYABORT or YYACCEPT.  */
   YYPOPSTACK (mu_cfg_yylen);
@@ -2006,7 +2059,7 @@ mu_cfg_yyreturn:
 
 
 
-/* Line 1684 of yacc.c  */
+/* Line 2071 of yacc.c  */
 #line 388 "parser.y"
 
 
@@ -2793,7 +2846,7 @@ _set_fun (void *item, void *data)
   void *tgt;
   size_t size;
   
-  if (clos->type >= MU_ARRAY_SIZE(config_type_size)
+  if ((size_t) clos->type >= MU_ARRAY_SIZE(config_type_size)
       || (size = config_type_size[clos->type]) == 0)
     {
       mu_diag_at_locus (MU_LOG_EMERG, clos->locus,
