@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2003-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999-2001, 2003-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -48,12 +49,12 @@ static char *_mu_mailbox_pattern;
 static char *_default_folder_dir = "Mail";
 static char *_mu_folder_dir;
 
+#define USERSUFFIX "${user}"
+
 static int
 mu_normalize_mailbox_url (char **pout, const char *dir)
 {
   int len;
-  int addslash = 0;
-#define USERSUFFIX "${user}"
   
   if (!pout)
     return MU_ERR_OUT_PTR_NULL;
@@ -61,23 +62,22 @@ mu_normalize_mailbox_url (char **pout, const char *dir)
   len = strlen (dir);
   if (dir[len-1] == '=')
     {
-      if (len > 5 && strcmp (dir + len - 5, "user=") == 0)
-	*pout = strdup (dir);
-      else
+      if (!(len > 5 && strcmp (dir + len - 5, "user=") == 0))
 	return MU_ERR_BAD_FILENAME;
+      else
+	{
+	  int rc = mu_asprintf (pout, "%s%s", dir, USERSUFFIX);
+	  if (rc)
+	    return rc;
+	}
     }
-  else if (dir[len-1] != '/')
-    addslash = 1;
-
-  *pout = malloc (strlen (dir) + (addslash ? 1 : 0) + sizeof USERSUFFIX);
-  if (!*pout)
-    return ENOMEM;
-
-  strcpy (*pout, dir);
-  if (addslash)
-    strcat (*pout, "/");
-  strcat (*pout, USERSUFFIX);
-#undef USERSUFFIX
+  else
+    {
+      *pout = mu_make_file_name (dir, USERSUFFIX);
+      if (!*pout)
+	return errno;
+    }
+  
   return 0;
 }
 
@@ -128,9 +128,9 @@ mu_set_folder_directory (const char *p)
 const char *
 mu_mailbox_url ()
 {
-  if (!_mu_mailbox_pattern)
-    mu_set_mail_directory (MU_PATH_MAILDIR);
-  return _mu_mailbox_pattern;
+  if (_mu_mailbox_pattern)
+    return _mu_mailbox_pattern;
+  return MU_PATH_MAILDIR "/" USERSUFFIX;
 }
 
 const char *
@@ -144,6 +144,7 @@ mu_folder_directory ()
 int
 mu_construct_user_mailbox_url (char **pout, const char *name)
 {
+  int rc;
   const char *pat = mu_mailbox_url ();
   const char *env[3];
   struct mu_wordsplit ws;
@@ -152,13 +153,15 @@ mu_construct_user_mailbox_url (char **pout, const char *name)
   env[1] = (char*) name;
   env[2] = NULL;
   ws.ws_env = env;
-  if (mu_wordsplit (pat, &ws,
-		    MU_WRDSF_NOSPLIT | MU_WRDSF_NOCMD |
-		    MU_WRDSF_ENV | MU_WRDSF_ENV_KV))
+  rc = mu_wordsplit (pat, &ws,
+		     MU_WRDSF_NOSPLIT | MU_WRDSF_NOCMD |
+		     MU_WRDSF_ENV | MU_WRDSF_ENV_KV);
+    
+  if (rc)
     {
       mu_error (_("cannot expand line `%s': %s"), pat,
 		mu_wordsplit_strerror (&ws));
-      return errno;
+      return rc;
     }
 
   if (ws.ws_wordc == 0)
@@ -172,9 +175,6 @@ mu_construct_user_mailbox_url (char **pout, const char *name)
   return 0;
 }
 
-/* Is this a security risk?  */
-#define USE_ENVIRON 1
-
 static int
 split_shortcut (const char *file, const char pfx[], char **user, char **rest)
 {
@@ -238,7 +238,6 @@ get_homedir (const char *user)
     }
   else
     {
-#ifdef USE_ENVIRON
       /* NOTE: Should we honor ${HOME}?  */
       homedir = getenv ("HOME");
       if (homedir == NULL)
@@ -247,11 +246,6 @@ get_homedir (const char *user)
 	  if (auth)
 	    homedir = auth->dir;
         }
-#else
-      auth = mu_get_auth_by_name (user);
-      if (auth)
-	homedir = auth->dir;
-#endif
     }
 
   if (homedir)
@@ -263,10 +257,8 @@ get_homedir (const char *user)
 static int
 user_mailbox_name (const char *user, char **mailbox_name)
 {
-#ifdef USE_ENVIRON
   if (!user)
     user = (getenv ("LOGNAME")) ? getenv ("LOGNAME") : getenv ("USER");
-#endif
 
   if (user)
     {
@@ -295,7 +287,6 @@ plus_expand (const char *file, char **buf)
 {
   char *home;
   const char *folder_dir = mu_folder_directory ();
-  int len;
 
   home = get_homedir (NULL);
   if (!home)
@@ -305,17 +296,16 @@ plus_expand (const char *file, char **buf)
   
   if (folder_dir[0] == '/' || mu_is_proto (folder_dir))
     {
-      len = strlen (folder_dir) + strlen (file) + 2;
-      *buf = malloc (len);
-      sprintf (*buf, "%s/%s", folder_dir, file);
+      *buf = mu_make_file_name (folder_dir, file);
+      if (!*buf)
+	return errno;
     }
   else
     {
-      len = strlen (home) + strlen (folder_dir) + strlen (file) + 3;
-      *buf = malloc (len);
-      sprintf (*buf, "%s/%s/%s", home, folder_dir, file);
+      int rc = mu_asprintf (buf, "%s/%s/%s", home, folder_dir, file);
+      if (rc)
+	return rc;
     }
-  (*buf)[len-1] = 0;
   
   free (home);
   return 0;
@@ -415,10 +405,8 @@ mu_mailbox_create_default (mu_mailbox_t *pmbox, const char *mail)
 	     use FOLDER instead, to not confuse others by using MAIL.  */
 	  mail = getenv ("FOLDER");
 	  if (!mail)
-	    {
-	      /* Fallback to well-known environment.  */
-	      mail = getenv ("MAIL");
-	    }
+	    /* Fallback to well-known environment.  */
+	    mail = getenv ("MAIL");
 	}
 
       if (!mail)
@@ -428,7 +416,7 @@ mu_mailbox_create_default (mu_mailbox_t *pmbox, const char *mail)
 	  mail = tmp_mbox;
 	}
     }
-
+  
   p = mu_tilde_expansion (mail, MU_HIERARCHY_DELIMITER, NULL);
   if (tmp_mbox)
     free (tmp_mbox);
@@ -436,7 +424,7 @@ mu_mailbox_create_default (mu_mailbox_t *pmbox, const char *mail)
   mail = tmp_mbox;
   if (!mail)
     return ENOMEM;
-  
+
   switch (mail[0])
     {
     case '%':
@@ -450,18 +438,25 @@ mu_mailbox_create_default (mu_mailbox_t *pmbox, const char *mail)
 
     case '/':
       mbox = strdup (mail);
+      if (!mbox)
+	status = errno;
       break;
       
     default:
       if (!mu_is_proto (mail))
 	{
 	  p = mu_getcwd();
-	  mbox = malloc (strlen (p) + strlen (mail) + 2);
-	  sprintf (mbox, "%s/%s", p, mail);
+	  mbox = mu_make_file_name (p, mail);
+	  if (!mbox)
+	    status = errno;
 	  free (p);  
 	}
       else
-	mbox = strdup (mail);
+	{
+	  mbox = strdup (mail);
+	  if (!mbox)
+	    status = errno;
+	}
       break;
     }
 
