@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012 Free Software Foundation, Inc.
+   Copyright (C) 2011-2012, 2014-2015 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,11 +37,11 @@ call_action (struct action_closure *clos, size_t i)
   size_t n;
   int cmd;
   
-  if (clos->msgset->flags != (clos->flags & MU_MSGSET_MODE_MASK))
+  if (_MU_MSGSET_MODE (clos->msgset->flags) != _MU_MSGSET_MODE (clos->flags))
     {
       int rc;
 
-      switch (clos->flags & MU_MSGSET_MODE_MASK)
+      switch (_MU_MSGSET_MODE (clos->flags))
 	{
 	case MU_MSGSET_NUM:
 	  cmd = MU_MAILBOX_UID_TO_MSGNO;
