@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012 Free Software Foundation, Inc.
+   Copyright (C) 2011-2012, 2014-2015 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ mu_msgset_sub (mu_msgset_t a, mu_msgset_t b)
     return EINVAL;
   if (!b)
     return 0;
-  closure.mode = b->flags;
+  closure.mode = _MU_MSGSET_MODE (b->flags);
   closure.dest = a;
   return mu_list_foreach (b->list, sub_range, &closure);
 }
