@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2008-2012 Free Software Foundation, Inc.
+   Copyright (C) 2008-2012, 2014-2015 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -43,6 +43,7 @@
 #include <mailutils/acl.h>
 #include <mailutils/sockaddr.h>
 #include <mailutils/url.h>
+#include <mailutils/util.h>
 
 typedef RETSIGTYPE (*mu_sig_handler_t) (int);
 
@@ -391,7 +392,7 @@ mu_m_server_get_hints (mu_m_server_t srv, struct mu_sockaddr_hints *hints)
 {
   if (!hints)
     return EINVAL;
-  memcpy (hints, &srv->hints, sizeof (hints));
+  memcpy (hints, &srv->hints, sizeof (*hints));
   return 0;
 }
 
@@ -519,6 +520,7 @@ mu_m_server_begin (mu_m_server_t msrv)
 	  mu_error (_("failed to become a daemon: %s"), mu_strerror (errno));
 	  exit (EXIT_FAILURE);
 	}
+      mu_onexit_reset ();
     }
 
   if (msrv->pidfile)
@@ -917,7 +919,7 @@ static struct mu_cfg_param dot_server_cfg_param[] = {
 static struct mu_cfg_param server_cfg_param[] = {
   { "single-process", mu_cfg_bool, 
     NULL, mu_offsetof (struct mu_srv_config, single_process), NULL,
-    N_("Run this server in foreground.") },
+    N_("Do not spawn sub-process to handle requests in this server.") },
   { "transcript", mu_cfg_bool,
     NULL, mu_offsetof (struct mu_srv_config, transcript), NULL,
     N_("Log the session transcript.") },
