@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012 Free Software Foundation, Inc.
+   Copyright (C) 2011-2012, 2014-2015 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -62,7 +62,7 @@ mu_sockaddr_from_url (struct mu_sockaddr **retval, mu_url_t url,
     memcpy (&hints, mh, sizeof (hints));
   else
     {
-      memset (&hints, sizeof(hints), 0);
+      memset (&hints, 0, sizeof(hints));
       hints.family = AF_UNSPEC;
       hints.socktype = SOCK_STREAM;
       hints.protocol = IPPROTO_TCP;
