@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012 Free Software Foundation, Inc.
+   Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -149,7 +149,7 @@ filter_read (mu_stream_t stream, char *buf, size_t size, size_t *pret)
 	      if (rdsize == 0 &&
 		  MFB_RDBYTES (fs->outbuf) == 0 &&
 		  MFB_RDBYTES (fs->inbuf) == 0)
-		cmd = mu_filter_lastbuf;
+		break;
 	      
 	      MFB_advance_level (&fs->inbuf, rdsize);
 	    }
