@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012 Free Software Foundation, Inc.
+   Copyright (C) 2009-2012, 2014-2015 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -371,6 +371,8 @@ mu_stream_strerror (mu_stream_t stream, int rc)
 {
   const char *str;
 
+  if (!stream)
+    return mu_strerror (rc);
   if (stream->error_string)
     str = stream->error_string (stream, rc);
   else
@@ -520,7 +522,7 @@ _stream_skip_input_bytes (mu_stream_t stream, mu_off_t count, mu_off_t *pres)
 	{
 	  for (pos = 0;;)
 	    {
-	      if (stream->pos == stream->level)
+	      if (pos || stream->level == 0)
 		{
 		  if ((rc = _stream_flush_buffer (stream, _MU_STR_FLUSH_ALL)))
 		    return rc;
