@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2000, 2004, 2006-2007, 2010-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2000, 2004, 2006-2007, 2010-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -167,7 +167,7 @@ _tcp_ioctl (mu_stream_t stream, int code, int opcode, void *ptr)
 	  switch (opcode)
 	    {
 	    case MU_IOCTL_OP_GET:
-	      ptrans[0] = (mu_transport_t) tcp->fd;
+	      ptrans[0] = (mu_transport_t) (intptr_t) tcp->fd;
 	      ptrans[1] = NULL;
 	      break;
 	    case MU_IOCTL_OP_SET:
