@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2003, 2005-2007, 2009-2012 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2003, 2005-2007, 2009-2012, 2014-2015 Free
+   Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
