@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2012 Free Software Foundation, Inc.
+   Copyright (C) 2011-2012, 2014-2015 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,7 @@
 #include <mailutils/util.h>
 
 char *
-mu_stpcpy (char *p, char *q)
+mu_stpcpy (char *p, const char *q)
 {
   if (q)
     while ((*p = *q++))
