@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2005, 2007, 2010-2012 Free Software Foundation,
-   Inc.
+   Copyright (C) 2003-2005, 2007, 2010-2012, 2014-2015 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -332,6 +332,8 @@ ictl_ins (mu_iterator_t itr, int argc, char **argv)
       rc = mu_iterator_ctl (itr, mu_itrctl_insert_list, tmp);
       mu_list_destroy (&tmp);
     }
+  if (rc)
+    printf ("%s\n", mu_strerror (rc));
 }
 
 void
